==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesMo.php <==
<?php
/** Moldavian (Молдовеняскэ)
 *
 * @ingroup Language
 * @file
 *
 * @author Node ue
 * @author לערי ריינהארט
 */

$fallback = 'ro';

$messages = array(
# Dates
'sun'       => 'Дум',
'january'   => 'януарие',
'february'  => 'фебруарие',
'march'     => 'мартие',
'april'     => 'априлие',
'may_long'  => 'май',
'june'      => 'юние',
'july'      => 'юлие',
'august'    => 'аугуст',
'september' => 'септембрие',
'october'   => 'октомбрие',
'november'  => 'ноембрие',
'december'  => 'дечембрие',
'jan'       => 'яну',
'feb'       => 'феб',
'mar'       => 'мар',
'apr'       => 'апр',
'may'       => 'май',
'jun'       => 'юни',
'jul'       => 'юли',
'aug'       => 'ауг',
'sep'       => 'сеп',
'oct'       => 'окт',
'nov'       => 'ное',
'dec'       => 'деч',

'mytalk' => 'Дискуцииле меле',

'tagline'          => 'Де ла {{SITENAME}}',
'help'             => 'Ажутор',
'search'           => 'Каутэ',
'searchbutton'     => 'Каутэ',
'searcharticle'    => 'Дуче',
'printableversion' => 'Версиуне де типэрит',
'permalink'        => 'Легэтурэ неынчетатэ',
'edit'             => 'Editează - Едитязэ',
'talkpagelinktext' => 'Дискуций',
'personaltools'    => 'Унелте персонале',
'talk'             => 'Дискуций',
'views'            => 'Визуализэрь',
'toolbox'          => 'Кутие де унелте',
'jumpto'           => 'Салт ла:',
'jumptonavigation' => 'nавигацие',
'jumptosearch'     => 'кэутаре',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Деспре {{SITENAME}}',
'aboutpage'            => 'Project:Деспре',
'disclaimers'          => 'Деклараций',
'disclaimerpage'       => 'Project:Декларацие ӂенералэ',
'mainpage'             => 'Прима паӂина',
'mainpage-description' => 'Прима паӂина',
'privacy'              => 'Политика де интимитате',
'privacypage'          => 'Project:Политика де интимитате',

'retrievedfrom'   => 'Адус де ла "$1"',
'editsection'     => 'едитязэ',
'editsectionhint' => 'Едитязэ секциуня: $1',
'toc'             => 'Таблэ де материй',
'site-rss-feed'   => '$1 Агрегат RSS',
'site-atom-feed'  => '$1 Агрегат Atom',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user'  => 'Паӂина утилизаторулуй',
'nstab-image' => 'Фишиер',

# Login and logout pages
'userlogin'  => 'Креазэ конт / Аутентификаре',
'userlogout' => 'Ынкиде сесиуня',

# Edit pages
'summary'     => 'Резумат',
'watchthis'   => 'Привеште ачастэ паӂинэ',
'showpreview' => 'Аратэ превизуализаре',

# History pages
'cur'  => 'акт',
'last' => 'преч',

# Diffs
'lineno'   => 'Линия $1:',
'editundo' => 'десфаче',

# Search results
'powersearch' => 'Каутэ',

# Preferences page
'mypreferences' => 'Преферинцеле меле',

# Recent changes
'hist'            => 'ист',
'minoreditletter' => 'м',
'newpageletter'   => 'Н',

# Recent changes linked
'recentchangeslinked' => 'Скимбарь корелате',

# Upload
'upload' => 'Тримите фишиер',

# Image description page
'filehist'      => 'Историкул фишиерулуй',
'filehist-user' => 'Утилизатор',
'imagelinks'    => 'Легэтурь',

# Miscellaneous special pages
'nbytes' => '{{PLURAL:$1|ун октет|$1 октець}}',

# Special:AllPages
'alphaindexline' => '$1 пынэ ла $2',

# Watchlist
'watchlist' => 'Паӂинь привите',
'watch'     => 'Привеште',

# Namespace form on various pages
'blanknamespace' => '(Принчиал)',

# What links here
'whatlinkshere'       => 'Че се лягэ аичь',
'whatlinkshere-links' => '← легэтурь',

# Block/unblock
'blocklink'    => 'блокязэ',
'contribslink' => 'контрибуций',

# Thumbnails
'thumbnail-more' => 'Екстинде',

# Tooltip help for the actions
'tooltip-pt-preferences'  => 'Преферинцеле меле',
'tooltip-pt-login'        => 'Есте ынкуражат сэ се аутентификэ, дешь ачест лукру ну есте облигаториу.',
'tooltip-pt-logout'       => 'Ынкиде сесиуня',
'tooltip-ca-talk'         => 'Дискуцие деспре артикол',
'tooltip-ca-edit'         => 'Поате едита ачастэ паӂинэ. Ле ругэм сэ превизуализязэ концинутул ынаинте де салваре.',
'tooltip-search'          => 'Кэутаре ын {{SITENAME}}',
'tooltip-n-mainpage'      => 'Визитязэ паӂина принчипалэ',
'tooltip-n-portal'        => 'Деспре проект, че поате фачя думнявоастрэ, унде гэсеште солуций.',
'tooltip-n-currentevents' => 'Гэсеште информаций деспре ынтымпларе курентэ',
'tooltip-n-recentchanges' => 'Листа ултимелор скимбэрь реализате ын ачест вики.',
'tooltip-n-randompage'    => 'Мерӂе спре о паӂинэ алятоаре',
'tooltip-n-help'          => 'Локул ын каре гэсешть ажутор.',
'tooltip-t-whatlinkshere' => 'Листа тутурор паӂинилор вики каре кондук спре ачастэ паӂинэ',
'tooltip-t-upload'        => 'Тримите имаӂинь сау фишиере медия',
'tooltip-t-specialpages'  => 'Листа тутурор паӂинилор де сервичиу',
'tooltip-save'            => 'Салвязэ скимбэриле тале',

# Special:SpecialPages
'specialpages' => 'Сервичий',

);

==> mediawiki-1.15.0rc1.tar.gz: mediawiki-1.15.0rc1/languages/messages/MessagesMo.php <==
<?php
/** Moldavian (Молдовеняскэ)
 *
 * @ingroup Language
 * @file
 *
 * @author Node ue
 * @author לערי ריינהארט
 */

$fallback = 'ro';

$specialPageAliases = array(
	'CreateAccount'             => array( 'КреареКонт' ),
	'Preferences'               => array( 'Преферинце' ),
	'Recentchanges'             => array( 'Модификэрьреченте' ),
);

$messages = array(
# Dates
'sun'       => 'Дум',
'january'   => 'януарие',
'february'  => 'фебруарие',
'march'     => 'мартие',
'april'     => 'априлие',
'may_long'  => 'май',
'june'      => 'юние',
'july'      => 'юлие',
'august'    => 'аугуст',
'september' => 'септембрие',
'october'   => 'октомбрие',
'november'  => 'ноембрие',
'december'  => 'дечембрие',
'jan'       => 'яну',
'feb'       => 'феб',
'mar'       => 'мар',
'apr'       => 'апр',
'may'       => 'май',
'jun'       => 'юни',
'jul'       => 'юли',
'aug'       => 'ауг',
'sep'       => 'сеп',
'oct'       => 'окт',
'nov'       => 'ное',
'dec'       => 'деч',

'mytalk' => 'Дискуцииле меле',

'tagline'          => 'Де ла {{SITENAME}}',
'help'             => 'Ажутор',
'search'           => 'Каутэ',
'searchbutton'     => 'Каутэ',
'searcharticle'    => 'Дуче',
'printableversion' => 'Версиуне де типэрит',
'permalink'        => 'Легэтурэ неынчетатэ',
'edit'             => 'Editează - Едитязэ',
'talkpagelinktext' => 'Дискуций',
'personaltools'    => 'Унелте персонале',
'talk'             => 'Дискуций',
'views'            => 'Визуализэрь',
'toolbox'          => 'Кутие де унелте',
'jumpto'           => 'Салт ла:',
'jumptonavigation' => 'nавигацие',
'jumptosearch'     => 'кэутаре',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Деспре {{SITENAME}}',
'aboutpage'            => 'Project:Деспре',
'disclaimers'          => 'Деклараций',
'disclaimerpage'       => 'Project:Декларацие ӂенералэ',
'mainpage'             => 'Прима паӂина',
'mainpage-description' => 'Прима паӂина',
'privacy'              => 'Политика де интимитате',
'privacypage'          => 'Project:Политика де интимитате',

'retrievedfrom'   => 'Адус де ла "$1"',
'editsection'     => 'едитязэ',
'editsectionhint' => 'Едитязэ секциуня: $1',
'toc'             => 'Таблэ де материй',
'site-rss-feed'   => '$1 Агрегат RSS',
'site-atom-feed'  => '$1 Агрегат Atom',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user'  => 'Паӂина утилизаторулуй',
'nstab-image' => 'Фишиер',

# Login and logout pages
'userlogin'  => 'Креазэ конт / Аутентификаре',
'userlogout' => 'Ынкиде сесиуня',

# Edit pages
'summary'     => 'Резумат:',
'watchthis'   => 'Привеште ачастэ паӂинэ',
'showpreview' => 'Аратэ превизуализаре',

# History pages
'cur'  => 'акт',
'last' => 'преч',

# Diffs
'lineno'   => 'Линия $1:',
'editundo' => 'десфаче',

# Search results
'powersearch' => 'Каутэ',

# Preferences page
'mypreferences' => 'Преферинцеле меле',

# Recent changes
'hist'            => 'ист',
'minoreditletter' => 'м',
'newpageletter'   => 'Н',

# Recent changes linked
'recentchangeslinked' => 'Скимбарь корелате',

# Upload
'upload' => 'Тримите фишиер',

# File description page
'filehist'      => 'Историкул фишиерулуй',
'filehist-user' => 'Утилизатор',
'imagelinks'    => 'Легэтурь',

# Miscellaneous special pages
'nbytes' => '{{PLURAL:$1|ун октет|$1 октець}}',

# Special:AllPages
'alphaindexline' => '$1 пынэ ла $2',

# Watchlist
'watchlist' => 'Паӂинь привите',
'watch'     => 'Привеште',

# Namespace form on various pages
'blanknamespace' => '(Принчиал)',

# What links here
'whatlinkshere'       => 'Че се лягэ аичь',
'whatlinkshere-links' => '← легэтурь',

# Block/unblock
'blocklink'    => 'блокязэ',
'contribslink' => 'контрибуций',

# Thumbnails
'thumbnail-more' => 'Екстинде',

# Tooltip help for the actions
'tooltip-pt-preferences'  => 'Преферинцеле меле',
'tooltip-pt-login'        => 'Есте ынкуражат сэ се аутентификэ, дешь ачест лукру ну есте облигаториу.',
'tooltip-pt-logout'       => 'Ынкиде сесиуня',
'tooltip-ca-talk'         => 'Дискуцие деспре артикол',
'tooltip-ca-edit'         => 'Поате едита ачастэ паӂинэ. Ле ругэм сэ превизуализязэ концинутул ынаинте де салваре.',
'tooltip-search'          => 'Кэутаре ын {{SITENAME}}',
'tooltip-n-mainpage'      => 'Визитязэ паӂина принчипалэ',
'tooltip-n-portal'        => 'Деспре проект, че поате фачя думнявоастрэ, унде гэсеште солуций.',
'tooltip-n-currentevents' => 'Гэсеште информаций деспре ынтымпларе курентэ',
'tooltip-n-recentchanges' => 'Листа ултимелор скимбэрь реализате ын ачест вики.',
'tooltip-n-randompage'    => 'Мерӂе спре о паӂинэ алятоаре',
'tooltip-n-help'          => 'Локул ын каре гэсешть ажутор.',
'tooltip-t-whatlinkshere' => 'Листа тутурор паӂинилор вики каре кондук спре ачастэ паӂинэ',
'tooltip-t-upload'        => 'Тримите имаӂинь сау фишиере медия',
'tooltip-t-specialpages'  => 'Листа тутурор паӂинилор де сервичиу',
'tooltip-save'            => 'Салвязэ скимбэриле тале',

# Special:SpecialPages
'specialpages' => 'Сервичий',

);
